@@ -1,7 +1,7 @@
 use std::cell::RefCell;
 
 use rustc_hash::FxHashSet;
-use swc_atoms::JsWord;
+use swc_atoms::{js_word, JsWord};
 use swc_common::{collections::AHashSet, Mark, SyntaxContext};
 use swc_ecma_ast::*;
 use swc_ecma_utils::{find_ids, Id};
@@ -246,6 +246,11 @@ impl<'a> Resolver<'a> {
     }
 
     fn mark_for_ref_inner(&self, sym: &JsWord, stop_an_fn_scope: bool) -> Option<Mark> {
+        // NaN always points the globals
+        if *sym == js_word!("NaN") {
+            return Some(self.config.unresolved_mark);
+        }
+
         if self.config.handle_types && self.in_type {
             let mut mark = self.current.mark;
             let mut scope = Some(&self.current);
